@@ -6,6 +6,7 @@ import sys
 
 from fiona.ogrext import Iterator, Session, WritingSession
 from fiona.errors import DriverError, SchemaError, CRSError
+from fiona._drivers import DriverManager, driver_count
 from six import string_types
 
 class Collection(object):
@@ -61,6 +62,7 @@ class Collection(object):
         self._driver = None
         self._schema = None
         self._crs = None
+        self.driver_manager = None
         
         self.path = vsi_path(path, vsi, archive)
         
@@ -106,6 +108,11 @@ class Collection(object):
                     self._crs = crs
                 else:
                     raise CRSError("crs lacks init or proj parameter")
+        
+        if not self.driver_manager and driver_count() == 0:
+            # create a local manager and enter
+            self.driver_manager = DriverManager()
+            self.driver_manager.__enter__()
 
         if self.mode == "r":
             self.encoding = encoding
@@ -268,6 +275,8 @@ class Collection(object):
             self.session.stop()
             self.session = None
             self.iterator = None
+        if self.driver_manager:
+            self.driver_manager.__exit__()
 
     @property
     def closed(self):
